import { ArnPrincipal, CompositePrincipal, PolicyDocument } from '@aws-cdk/aws-iam';
import { Key, IKey } from '@aws-cdk/aws-kms';
import { Construct } from '@aws-cdk/core';
/**
 * @stability stable
 */
export interface IKmsEncryptionKeyProps {
    /**
     * @stability stable
     */
    readonly keyName: string;
    /**
     * @stability stable
     */
    readonly administratorRoleArns?: string[];
    /**
     * @stability stable
     */
    readonly environmentName?: string;
    /**
     * @stability stable
     */
    readonly description?: string;
}
/**
 * @stability stable
 */
export declare class KmsEncryptionKey extends Construct implements IKmsEncryptionKeyProps {
    /**
     * @stability stable
     */
    static getArnPrincipals(administratorRoleArns: string[]): ArnPrincipal[];
    /**
     * @stability stable
     */
    static getAdministratorArns(administratorRoleArns: string[]): CompositePrincipal[];
    /**
     * @stability stable
     */
    static createKeyPolicy(administratorRoleArns: string[]): PolicyDocument;
    /**
     * @stability stable
     */
    readonly kmsKey: IKey;
    /**
     * @stability stable
     */
    readonly description?: string;
    /**
     * @stability stable
     */
    readonly keyName: string;
    /**
     * @stability stable
     */
    readonly environmentName?: string;
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, props?: IKmsEncryptionKeyProps);
    /**
     * @stability stable
     */
    getKeyName(keyName?: string): string;
    /**
     * @stability stable
     */
    createKmsKey(administratorRoleArns: string[]): Key;
    /**
     * @stability stable
     */
    addTags(): void;
}
